@@ -2,11 +2,9 @@
 #'
 #' Return a named list of standard folder names. Save a config file if missing.
 #' @param conf_file (character) Configuration file to read/write.
-#'     See: config::get().
+#'     See: config::get(). (Default: NULL)
 #' @param conf_name (character) Name of configuration to read.
 #'     See: config::get(). (Default: Sys.getenv("R_CONFIG_NAME"))
-#' @param save_conf (boolean) Whether or not to save new configuration file.
-#'     (Default: TRUE)
 #' @return (list) The named folders for a standard file structure, will be
 #'     returned as a list.
 #' @keywords consistency
@@ -23,15 +21,15 @@
 #' list from a non-default section of the configuration file, set the name of
 #' the section with the "conf_name" parameter.
 #' @examples
-#' conf_file <- tempfile("folders.yml")
+#' folders <- get_folders()                 # Configuration file not used
+#' conf_file <- tempfile("folders.yml")     # Using tempfile() for testing only
 #' folders <- get_folders(conf_file)
 #' folders <- get_folders(conf_file, conf_name = "custom")
 #' Sys.setenv(R_CONFIG_NAME = "custom")
 #' folders <- get_folders(conf_file)
 #' @export
 get_folders <- function(conf_file = NULL, 
-                        conf_name = Sys.getenv('R_CONFIG_NAME'),
-                        save_conf = TRUE) {
+                        conf_name = Sys.getenv('R_CONFIG_NAME')) {
   if(!is.null(conf_file) && file.exists(conf_file)) {
     conf_name <- ifelse(conf_name == '', 'default', conf_name)
     folders <- config::get(config = conf_name, file = conf_file)
@@ -44,7 +42,7 @@ get_folders <- function(conf_file = NULL,
       figures = 'figures',
       results = 'results'
     )
-    if (!is.null(conf_file) && save_conf) {
+    if (!is.null(conf_file)) {
       dir.create(dirname(conf_file), recursive = TRUE, showWarnings = FALSE)
       yaml::write_yaml(list(default = folders), file = conf_file)
     }
